#include <QMimeData>
#include <QUrl>
#include <QDebug>
#include <QPainter>
#include <QIcon>
#include <gsettingmonitor.h>
#include <usermanual.h>
#include <QPainterPath>
#include "blankpage.h"


const QSize IMAGESIZE = QSize(128, 128);

BlankPage::BlankPage(QWidget *parent)
    : QWidget(parent)
{
    setWidgetUi();
    initLayout();
    initGsetting();
}

BlankPage::~BlankPage()
{
}

void BlankPage::setWidgetUi()
{
    m_blankLabel = new QLabel(this);

    m_blankTextLabel = new QLabel(this);

    m_blankTextLabel->setText(tr("No Font"));
    QString labGrayStyle = "color:#8C8C8C;";
    m_blankTextLabel->setStyleSheet(labGrayStyle);
    m_blankTextLabel->setFixedWidth(128);
    m_blankTextLabel->setAlignment(Qt::AlignHCenter);

    QFont font14;
    double g_fontSize = kdk::GsettingMonitor::getSystemFontSize().toDouble();
    double g_font14pxToPt = (g_fontSize * (14.00 / 11)) - 3;
    font14.setPointSizeF(g_font14pxToPt);
    m_blankTextLabel->setFont(font14);

    m_vLayout = new QVBoxLayout();
    m_hLayout = new QHBoxLayout();
    return;
}

void BlankPage::initLayout()
{
    this->setMinimumSize(828, 156);
    this->setBackgroundRole(QPalette::Base);

    m_vLayout->addStretch();
    m_vLayout->addWidget(m_blankLabel);
    m_vLayout->addWidget(m_blankTextLabel);
    m_vLayout->addStretch();
    m_vLayout->setSpacing(0);
    m_vLayout->setMargin(0);

    m_hLayout->addStretch();
    m_hLayout->addLayout(m_vLayout);
    m_hLayout->addSpacing(IMAGESIZE.width() / 2);
    m_hLayout->addStretch();
    m_hLayout->setSpacing(0);
    m_hLayout->setMargin(0);

    this->setLayout(m_hLayout);
}

void BlankPage::paintEvent(QPaintEvent *event)
{
    Q_UNUSED(event);

    QPainter p(this);
    QPainterPath rectPath;
    p.fillPath(rectPath,palette().color(QPalette::Base));
    p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
    return;
}

void BlankPage::initGsetting()
{
}

void BlankPage::changeSearchText()
{
    m_blankTextLabel->setText(tr("No Search Results"));
}

void BlankPage::changeBlankText()
{
    m_blankTextLabel->setText(tr("No Font"));
}
